Module: RobotLab::RactorPool
- Defined in:
- lib/robot_lab/ractor/version.rb
Overview
RactorPool (not Ractor) avoids shadowing Ruby’s built-in Ractor class for all code within the RobotLab namespace.
Constant Summary collapse
- VERSION =
"0.1.0"
RactorPool (not Ractor) avoids shadowing Ruby’s built-in Ractor class for all code within the RobotLab namespace.
"0.1.0"